is_leading_byte_width_2

Function is_leading_byte_width_2 

pub open spec fn is_leading_byte_width_2(byte: u8) -> bool
{ 0xc0 <= byte <= 0xdf }

True when the given byte conforms to the bit pattern for the first byte of a 2-byte UTF-8 encoding of a single codepoint. The byte must have the form 110xxxxx.