is_leading_byte_width_4

Function is_leading_byte_width_4 

pub open spec fn is_leading_byte_width_4(byte: u8) -> bool
{ 0xf0 <= byte <= 0xf7 }

True when the given byte conforms to the bit pattern for the first byte of a 4-byte UTF-8 encoding of a single codepoint. The byte must have the form 11110xxx.