leading_bits_width_3

Function leading_bits_width_3 

pub open spec fn leading_bits_width_3(byte: u8) -> u32
recommends
is_leading_byte_width_3(byte),
{ (byte & 0x0F) as u32 }

Value of the 4 data bits from the given byte, assuming that it is a valid leading byte for a 3-byte UTF-8 encoding.