not_surrogate

Function not_surrogate 

pub open spec fn not_surrogate(codepoint: u32) -> bool
{ !(0xD800 <= codepoint <= 0xDFFF) }

True when the given codepoint does not fall into the “surrogate range” of the Unicode standard. The surrogate range contains values which are technically possible to encode in UTF-8 but are not valid Unicode scalars.