pub open spec fn codepoint_width_1(byte1: u8) -> u32Expand description
recommends
is_leading_byte_width_1(byte1),{ leading_bits_width_1(byte1) }The codepoint encoded by the given byte, assuming that it is a valid leading byte for a 1-byte UTF-8 encoding.