pub open spec fn continuation_bits(byte: u8) -> u32Expand description
recommends
is_continuation_byte(byte),{ (byte & 0x3f) as u32 }Value of the 6 data bits from the given continuation byte, assuming that it is a valid continuation byte for a UTF-8 encoding.