pub open spec fn is_continuation_byte(byte: u8) -> boolExpand description
{ 0x80 <= byte <= 0xbf }True when the given byte conforms to the bit pattern for a continuation byte of a UTF-8 encoding of a single codepoint. The byte must have the form 10xxxxxx.