pub open spec fn is_leading_byte_width_3(byte: u8) -> boolExpand description
{ 0xe0 <= byte <= 0xef }True when the given byte conforms to the bit pattern for the first byte of a 3-byte UTF-8 encoding of a single codepoint. The byte must have the form 1110xxxx.