pub open spec fn leading_bits_width_2(byte: u8) -> u32Expand description
recommends
is_leading_byte_width_2(byte),{ (byte & 0x1F) as u32 }Value of the 5 data bits from the given byte, assuming that it is a valid leading byte for a 2-byte UTF-8 encoding.