pub open spec fn leading_bits_width_4(byte: u8) -> u32Expand description
recommends
is_leading_byte_width_4(byte),{ (byte & 0x07) as u32 }Value of the 3 data bits from the given byte, assuming that it is a valid leading byte for a 4-byte UTF-8 encoding.